
% natl_heatflux.m
%
% Calculate the net northward heat flux in
% the North Atlantic Ocean from the UWM/COADS
% mean net heat flux, as in Budyko (1963).

clear all;

% load COADS fields
[lon_coads,lat_coads,lonvec,latvec,sss,index, ...
         sst,netheat,eminusp,taux,tauy]=loadcoadsyear(-99);

% discard values outside N. Atl.
disp('Isolating North Atlantic.');
load atlcoords x y
q=~isinpoly(lonvec,latvec,x,y);
truncatecoads
clear sss sst eminusp taux tauy x y q n;

% calculate net heat flux
nummonths=size(netheat,1);
q=NaN*ones(length(lat_coads),length(lon_coads));
Q=NaN*ones(length(lat_coads),length(lon_coads),nummonths);
for mn=1:nummonths;
  q(index)=netheat(mn,:);
  Q(:,:,mn)=q;
end;
clear q;
Q=mean(Q,3);
% convert from W/m^2 to W
Area=sw_area(lon_coads,lat_coads);
Q=Q.*Area;

% now calculate oceanic heat flux as a function of latitude:
%   all heat loss north of latitude phi must be imported
%   by the ocean.
F=NaN*ones(size(lat_coads));
for i=1:length(lat_coads);
  q=find(lat_coads>lat_coads(i));
  F(i)=-nansum(nansum(Q(q,:)));
end;

clf;

subplot(121);
pcolor2(lon_coads,lat_coads,Q./Area);
set(gca,'dataaspectratio',[1 1 1]);
title('UWM/COADS net heat flux (W/m^2)');

subplot(122);
plot(F/1e15,lat_coads,'k');
title('Inferred oceanic heat flux (PW)')
grid on;
