% sstindices - calculate monly SSTA in various
%   regions

clear all;
% define regions
LonReg{1}=[-150 -90]; LatReg{1}=[-5 5]; NameReg{1}='NINO3';
LonReg{2}=[-60 -30]; LatReg{2}=[5 25]; NameReg{2}='TNA';
LonReg{3}=[-30 0]; LatReg{3}=[-25 -5]; NameReg{3}='TSA';
LonReg{4}=[-35 0]; LatReg{4}=[-5 5]; NameReg{4}='AtlNINO';

Year=1950:1989;

% load monthly mean SST
[Lon,Lat,lonvec,latvec,sss,index, ...
	    sstB,netheat,eminusp,taux,tauy]=loadcoadsyear(-99);

SSTp=NaN*ones(12*length(Year),length(LonReg));
for yind=1:length(Year);
    [lon_coads,lat_coads,lonvec,latvec,sss,index, ...
	    sst,netheat,eminusp,taux,tauy]=loadcoadsyear(Year(yind));
    % convert to anomaly
    sst=sst-sstB;
    monind=12*(yind-1)+1:12*yind;
    for i=1:length(LonReg);
        q=find(latvec>=min(LatReg{i}) & latvec<=max(LatReg{i}) & ...
            lonvec>=min(LonReg{i}) & lonvec<=max(LonReg{i}));
        SSTp(monind,i)=nanmean2(sst(:,q),2);
    end;
end;

T=min(Year)+.5/12:1/12:max(Year)+11.5/12;
month=round(12*(T-floor(T))+.5);
       
clear lonvec latvec Lon Lat sss index sst* netheat
clear eminusp taux tauy i monind q yind *coads



% calculate DJ Nino3
q=find(month==12 | month==1);
% drop first Jan, last Dec
q=q(2:length(q)-1);
n3=NaN*ones(length(q)/2,1); t3=n3;
ind=1;
for i=1:length(n3)
    n3(i)=mean(SSTp(q(ind:ind+1),1));
    t3(i)=mean(T(q(ind:ind+1)));
    ind=ind+2;
end;

% calculate MAM TNA and TSA
q=find(month==3 | month==4 | month==5);
tna=NaN*ones(length(q)/3,1); 
tsa=tna; t=tna;
ind=1;
for i=1:length(tna)
    tna(i)=mean(SSTp(q(ind:ind+2),2));
    tsa(i)=mean(SSTp(q(ind:ind+2),3));
    t(i)=mean(T(q(ind:ind+2)));
    ind=ind+3;
end;
% drop first year, so values can be plotted
% against preceding Dec-Jan Nino3
t=t(2:length(t));
tna=tna(2:length(tna));
tsa=tsa(2:length(tsa));

clf;
qwarm=find(n3>=1);
qcold=find(n3<=-.75);
qneut=find(n3>-.75 & n3<1);

for plt=1:4;
    if (plt==1) 
        x=tna-tsa; y=n3; 
        xlab='TNA-TSA MAM(1)'; ylab='Nino-3 DJ(0)';
    elseif (plt==2)
        x=tna; y=tsa;
        xlab='TNA MAM(1)'; ylab='TSA MAM(1)';
    elseif (plt==3)
        x=tna; y=n3;
        xlab='TNA MAM(1)'; ylab='Nino-3 DJ(0)';
    else
        x=tsa; y=n3;
        xlab='TSA MAM(1)'; ylab='Nino-3 DJ(0)';
    end;
    subplot(2,2,plt)
    plot(x(qneut),y(qneut),'.k',x(qwarm),y(qwarm),'.r', ...
        x(qcold),y(qcold),'.b','markersize',15);
    asprat;
    xlabel(xlab); ylabel(ylab);
    %axis([-3 3 -3 3])
    set(gca,'xtick',-3:3,'ytick',-3:3);
    [r,p]=corrcoef([x,y]);
    r=r(1,2);p=p(1,2);
    if (p<.01) p=.01; end;
    ttl=['Corr: ',num2str(r,'%3.2f'), ...
        ];
          %  ', Sig: ',num2str(100-100*p,'%2.0f'),'%'];
    title(ttl,'fontsize',10);
end;
